@@ -289,6 +289,20 @@ mag_zoomer_set_source (MagZoomer *mag_zoomer,
 			    	     mag_zoomer->source);
 }
 
+void 
+mag_zoomer_set_target (MagZoomer *mag_zoomer, 
+			gchar     *target)
+{
+	if (mag_zoomer->target) 
+	{
+	    g_free (mag_zoomer->target);	
+	    mag_zoomer->target = NULL;
+	}
+	mag_zoomer->target = g_strdup (target);
+
+	magnifier_set_target_screen (magnifier, 
+			    	     mag_zoomer->target);
+}
 
 /* __ MAG ZOOMER PARAMS METHODS ________________________________________________*/
 void 
