@@ -130,7 +130,7 @@ magnifier_get_source (GNOME_Magnifier_Magnifier 	magnifier,
 	if (properties)
 	{
 	    rectangle_any = Bonobo_PropertyBag_getValue (properties,
-    			    				 "source-display-bounds",
+    			    				 "source-display-size",
   							 &ev);
 	    check_return_value (&ev, __LINE__);
 	    rectangle = (GNOME_Magnifier_RectBounds *) rectangle_any->_value;
