@@ -19,8 +19,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __spgs_h
-#define __spgs_h
+#ifndef __SPGS_H__
+#define __SPGS_H__
 
 #include <libbonobo.h>
 #include <gnome-speech/gnome-speech.h>
@@ -37,4 +37,4 @@ int  	gs_init      	(TTSEngine 	*engine);
 void 	gs_terminate	(void);
 
 
-#endif
+#endif /* __SPGS_H__ */
